Module blaxel.core.client.models.resource_log_response
======================================================

Classes
-------

`ResourceLogResponse(chart: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, logs: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, total_count: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Response for a resource log
    
    Attributes:
        chart (Union[Unset, list[Any]]): Chart
        logs (Union[Unset, list[Any]]): Logs
        total_count (Union[Unset, int]): Total count of logs
    
    Method generated by attrs for class ResourceLogResponse.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `chart: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    `logs: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    `total_count: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :